/* This file is automatically generated. Any changes made here will be lost. */

/* This header defines simple perlapi-ish macros for creating SV wrappers
 * and extracting the GPerl value from SV wrappers.  These macros are used
 * by the autogenerated typemaps, and are defined here so that you can use
 * the same logic anywhere in your code (e.g., if you handle the argument
 * stack by hand instead of using the typemap). */

#ifdef XFCONF_TYPE_CHANNEL
  /* GObject derivative XfconfChannel */
# define SvXfconfChannel(sv)	((XfconfChannel*)gperl_get_object_check (sv, XFCONF_TYPE_CHANNEL))
# define newSVXfconfChannel(val)	(gperl_new_object (G_OBJECT (val), FALSE))
  typedef XfconfChannel XfconfChannel_ornull;
# define SvXfconfChannel_ornull(sv)	(gperl_sv_is_defined (sv) ? SvXfconfChannel(sv) : NULL)
# define newSVXfconfChannel_ornull(val)	(((val) == NULL) ? &PL_sv_undef : gperl_new_object (G_OBJECT (val), FALSE))
typedef XfconfChannel XfconfChannel_noinc;
#define newSVXfconfChannel_noinc(val)	(gperl_new_object (G_OBJECT (val), TRUE))
typedef XfconfChannel XfconfChannel_noinc_ornull;
#define newSVXfconfChannel_noinc_ornull(val)	((val) ? newSVXfconfChannel_noinc(val) : &PL_sv_undef)
#endif /* XFCONF_TYPE_CHANNEL */
